
#line 3 "giscanner/scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 163
#define YY_END_OF_BUFFER 164
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[1095] =
    {   0,
      164,  162,  163,    3,  162,  163,    1,  163,   45,  162,
      163,  162,  163,   20,  162,  163,   40,  162,  163,   42,
      162,  163,  162,  163,   29,  162,  163,   30,  162,  163,
       38,  162,  163,   36,  162,  163,   69,  162,  163,   37,
      162,  163,   35,  162,  163,   39,  162,  163,  155,  162,
      163,  155,  162,  163,   32,  162,  163,   31,  162,  163,
       47,  162,  163,   46,  162,  163,   48,  162,  163,   34,
      162,  163,  111,  152,  162,  163,  111,  152,  162,  163,
      111,  152,  162,  163,  111,  152,  162,  163,  111,  152,
      162,  163,   25,  162,  163,  162,  163,   27,  162,  163,

       41,  162,  163,  111,  152,  162,  163,  111,  152,  162,
      163,  111,  152,  162,  163,  111,  152,  162,  163,  111,
      152,  162,  163,  111,  152,  162,  163,  111,  152,  162,
      163,  111,  152,  162,  163,  111,  152,  162,  163,  111,
      152,  162,  163,  111,  152,  162,  163,  111,  152,  162,
      163,  111,  152,  162,  163,  111,  152,  162,  163,  111,
      152,  162,  163,  111,  152,  162,  163,   21,  162,  163,
       43,  162,  163,   23,  162,  163,   44,  162,  163,    3,
        1,   62,  160,   53,   24,   65,   55,  158,   51,   67,
       49,   68,   50,   70,  156,    4,    6,   52,  156,  154,

      155,  155,  155,  155,   28,   22,   26,   57,   63,   61,
       64,   58,  111,  152,  111,  152,  111,  152,  111,  152,
        2,   54,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  121,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  129,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,   56,   66,   33,  156,    6,  154,

      155,  154,  155,  157,  155,  155,  155,  153,   59,   60,
      111,  152,  111,  152,  161,  159,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  112,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  127,  152,  111,  152,  111,  152,  111,  131,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,

      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  156,  154,  155,
      154,  155,  154,  155,  157,  155,  153,  153,  111,  152,
      111,  152,  111,  152,  107,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      113,  152,  111,  114,  152,  111,  152,  111,  116,  152,

      111,  117,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  123,  152,  111,  124,  152,  111,  152,  111,
      152,  111,  152,  111,  128,  152,  111,  152,  111,  136,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  109,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  149,  152,  111,  152,  111,  152,   18,   13,  154,
      155,  153,  153,  153,  108,  111,  152,  111,  152,  111,
      152,   96,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,   74,  111,  152,  111,  152,  111,

      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  102,  111,  152,  111,  115,
      152,  111,  118,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  110,  111,  152,  111,  126,  152,  111,  152,
      111,  152,  111,  152,  111,  152,  111,  140,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  147,  152,  111,  152,  111,  152,
      111,  151,  152,   15,  153,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,

      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  122,  152,
      111,  125,  152,  111,  130,  152,  111,  152,  111,  152,
      111,  139,  152,  111,  141,  152,  111,  142,  152,  111,
      143,  152,  111,  144,  152,  111,  145,  152,  111,  152,
      111,  152,  111,  152,  111,  152,   14,   16,    5,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,   75,  111,  152,  111,  152,

       98,  111,  152,   78,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  103,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  120,  152,  111,  152,  111,  152,
      111,  152,  111,  146,  152,  111,  152,  111,  152,   12,
      111,  152,  111,  152,  111,  152,   83,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,   81,  111,  152,  111,  135,  152,  111,
      152,  111,  152,   87,  111,  152,  111,  152,   93,  111,
      152,  111,  152,  111,  152,  111,  119,  152,  111,  137,

      152,  111,  138,  152,  111,  152,  111,  148,  152,  111,
      150,  152,    8,   11,   19,   17,  111,  152,  111,  152,
      104,  111,  152,   86,  111,  152,  111,  152,   84,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,   82,  111,  152,  111,  152,  111,  152,
      101,  111,  152,  111,  134,  152,  111,  152,  111,  152,
        7,    8,  111,  152,  111,  152,  111,  152,  111,  152,
      111,  152,  111,  152,  111,  152,   80,  111,  152,  111,
      133,  152,   89,  111,  152,   88,  111,  152,  111,  152,
       94,  111,  152,  111,  152,  111,  152,  111,  152,  111,

      152,  111,  152,   77,  111,  152,  111,  152,  111,  152,
      111,  132,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,  111,  152,  111,  152,  111,  152,   90,
      111,  152,   95,  111,  152,   91,  111,  152,  111,  152,
      111,  152,  111,  152,   92,  111,  152,   76,  111,  152,
      100,   79,  111,  152,  111,  152,  111,  152,  111,  152,
       71,  111,  152,  111,  152,  111,  152,  111,  152,  111,
      152,  111,  152,   72,  105,  111,  152,  111,  152,   85,
      111,  152,  106,  111,  152,   73,    9,    9,   12,   10,
       10,   11,   99,   97

    } ;

static yyconst flex_int16_t yy_accept[733] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   89,   93,   96,   98,  101,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  164,  168,  171,  174,  177,  180,  181,  182,
      183,  183,  184,  184,  184,  184,  184,  184,  184,  184,
      185,  186,  187,  188,  188,  189,  189,  190,  191,  192,
      193,  194,  195,  195,  196,  197,  198,  199,  200,  202,
      203,  203,  204,  205,  205,  206,  207,  208,  209,  210,

      211,  212,  213,  215,  217,  219,  219,  219,  221,  222,
      223,  225,  227,  229,  231,  233,  235,  237,  239,  241,
      243,  245,  247,  249,  252,  254,  256,  258,  260,  262,
      264,  266,  269,  271,  273,  275,  277,  279,  281,  283,
      285,  287,  289,  291,  293,  295,  296,  297,  297,  297,
      297,  297,  297,  297,  297,  298,  298,  299,  299,  299,
      300,  302,  304,  304,  305,  306,  307,  308,  309,  310,
      311,  313,  315,  315,  316,  316,  316,  317,  317,  319,
      321,  323,  325,  327,  329,  331,  333,  335,  337,  339,
      341,  343,  345,  347,  349,  351,  353,  356,  358,  360,

      362,  364,  366,  368,  370,  372,  374,  376,  378,  380,
      382,  385,  387,  389,  392,  394,  396,  398,  400,  402,
      404,  406,  408,  410,  412,  414,  416,  418,  420,  422,
      424,  426,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  429,  429,  431,  433,  435,  436,
      437,  438,  439,  441,  443,  445,  448,  450,  452,  454,
      456,  458,  460,  462,  464,  466,  468,  470,  472,  474,
      476,  478,  480,  482,  484,  486,  488,  490,  493,  496,
      498,  501,  504,  506,  508,  510,  512,  515,  518,  520,
      522,  524,  527,  529,  532,  534,  536,  538,  540,  542,

      544,  546,  548,  550,  552,  555,  557,  559,  561,  564,
      566,  568,  568,  569,  569,  569,  569,  569,  569,  570,
      570,  570,  570,  570,  570,  572,  573,  574,  575,  578,
      580,  582,  585,  587,  589,  591,  593,  595,  598,  600,
      602,  604,  606,  608,  610,  612,  614,  616,  618,  620,
      622,  624,  626,  629,  632,  635,  637,  639,  641,  643,
      646,  649,  651,  653,  655,  657,  660,  662,  664,  666,
      668,  670,  672,  674,  677,  679,  681,  684,  684,  684,
      684,  685,  685,  685,  685,  685,  685,  685,  685,  686,
      688,  690,  692,  694,  696,  698,  700,  702,  702,  704,

      706,  708,  710,  712,  714,  716,  718,  720,  722,  724,
      726,  728,  730,  732,  734,  736,  738,  741,  744,  747,
      749,  751,  754,  757,  760,  763,  766,  769,  771,  773,
      775,  777,  777,  777,  778,  778,  779,  779,  779,  779,
      779,  779,  780,  782,  784,  786,  788,  790,  792,  794,
      796,  796,  799,  801,  804,  807,  809,  811,  813,  815,
      818,  820,  822,  824,  826,  828,  830,  832,  834,  837,
      839,  841,  843,  846,  848,  850,  850,  850,  850,  850,
      851,  851,  851,  851,  851,  851,  853,  855,  857,  860,
      862,  864,  866,  868,  868,  868,  870,  872,  874,  877,

      880,  882,  884,  887,  889,  892,  894,  896,  899,  902,
      905,  907,  907,  910,  913,  914,  914,  914,  914,  914,
      914,  915,  915,  915,  916,  916,  917,  919,  921,  924,
      927,  929,  932,  934,  934,  934,  934,  936,  938,  940,
      942,  944,  947,  949,  951,  954,  957,  959,  961,  961,
      962,  963,  963,  963,  963,  963,  965,  967,  969,  971,
      971,  971,  971,  973,  975,  977,  980,  983,  986,  989,
      991,  994,  996,  996,  996,  996,  996,  996,  998, 1000,
     1002, 1004, 1004, 1004, 1004, 1007, 1007, 1007, 1009, 1011,
     1014, 1016, 1018, 1018, 1018, 1018, 1018, 1018, 1020, 1022,

     1024, 1026, 1026, 1026, 1026, 1028, 1028, 1028, 1028, 1030,
     1033, 1036, 1039, 1039, 1039, 1039, 1039, 1039, 1041, 1043,
     1045, 1048, 1048, 1048, 1048, 1051, 1052, 1052, 1055, 1055,
     1055, 1055, 1055, 1055, 1057, 1059, 1061, 1062, 1062, 1062,
     1062, 1062, 1062, 1062, 1062, 1062, 1064, 1066, 1068, 1068,
     1068, 1068, 1068, 1068, 1068, 1068, 1068, 1070, 1072, 1074,
     1074, 1075, 1075, 1075, 1075, 1075, 1075, 1075, 1078, 1080,
     1083, 1083, 1083, 1083, 1083, 1083, 1083, 1083, 1086, 1086,
     1086, 1086, 1086, 1086, 1086, 1086, 1086, 1086, 1086, 1086,
     1086, 1086, 1086, 1087, 1087, 1087, 1087, 1087, 1087, 1087,

     1087, 1087, 1087, 1087, 1088, 1088, 1088, 1090, 1090, 1090,
     1090, 1090, 1090, 1090, 1091, 1091, 1091, 1093, 1093, 1093,
     1093, 1094, 1094, 1094, 1094, 1094, 1094, 1094, 1094, 1094,
     1095, 1095
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   23,   25,   23,   26,   27,   28,   29,   30,
       31,   32,   33,    1,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   41,   41,   43,   41,   44,   45,   41,
       41,   46,   47,   48,   49,   41,   41,   50,   41,   41,
       51,   52,   53,   54,   55,    1,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   71,   65,   72,   73,   74,   75,   76,   77,   78,
       79,   80,   81,   82,   83,   84,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[85] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    5,    1,    1,    1,    6,
        6,    6,    6,    6,    6,    6,    6,    1,    1,    1,
        5,    1,    1,    7,    7,    7,    7,    7,    7,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        1,    1,    1,    1,    8,    9,    9,    9,    9,    9,
        9,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
        1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[759] =
    {   0,
        0,    0, 1228, 1229,   83,    0, 1196,   79,   84,   59,
       82,   82, 1229, 1229, 1195,   79, 1229,   80,   78,   95,
      138,  199, 1193, 1229,   97, 1193,   76, 1229,    0, 1189,
     1167,  108, 1175, 1229, 1217, 1229, 1188,   85,   43,   51,
       76,   75,   69,  101, 1148,   61, 1147, 1156,  103,  106,
     1146, 1144, 1150, 1229,  110, 1229, 1229,  148,    0, 1229,
      130, 1229, 1209,  207, 1151,  103, 1149, 1145, 1136, 1229,
     1229, 1229, 1229,  131, 1229, 1204, 1229, 1229, 1229, 1229,
     1229, 1229, 1188,  255,  184,    0, 1229,    0,  195,    0,
      280,  197,  106,    0, 1229, 1229, 1229, 1174, 1229, 1229,

     1229, 1173,    0, 1160, 1162,  147,  163, 1152, 1229, 1229,
     1130, 1132,  109, 1135,  254, 1129, 1122, 1125, 1134, 1120,
     1136, 1122, 1129, 1114, 1115, 1112, 1112, 1118, 1114, 1111,
     1108,    0,  123, 1112,  129, 1110,  113,  138, 1115, 1106,
     1102, 1105,  131,  142, 1111, 1229, 1229,  230, 1113,  185,
     1114,  202, 1103, 1115, 1229,  317, 1229, 1140,    0,    0,
      242,  169,  325,  333,  190, 1229,  200,  318, 1229, 1229,
     1122,  159,  189, 1229, 1165,  236, 1229, 1164, 1128, 1095,
     1094,  191, 1096, 1090,  195,  141, 1101, 1082, 1090, 1088,
     1097,  222, 1077, 1091, 1084, 1128,    0, 1082, 1084, 1094,

     1089, 1076,  210, 1091, 1089, 1085, 1076, 1083, 1069, 1085,
        0, 1070, 1075,    0, 1076, 1073, 1062, 1060, 1062, 1064,
     1072, 1057, 1055, 1055, 1068, 1067, 1066, 1055, 1060, 1064,
     1066, 1054, 1117, 1055, 1057, 1057, 1052, 1112, 1054, 1054,
     1052, 1049,  357,  381, 1078,  250, 1229,  244, 1229, 1229,
      320,  319, 1071, 1064, 1065,    0, 1039, 1049, 1035, 1043,
     1035, 1041, 1032, 1025, 1038, 1028, 1038, 1021,  297, 1025,
     1020, 1030, 1032, 1019, 1020, 1021, 1063,    0,    0, 1020,
        0,    0, 1011, 1020, 1008, 1015,    0,    0, 1009, 1020,
     1005,    0, 1009,    0, 1004, 1004, 1003, 1000, 1013, 1002,

     1007, 1012, 1011, 1012,    0, 1008,  997, 1003,    0,  990,
     1003, 1059, 1229,  992, 1055, 1056,  997, 1054, 1229,  995,
      995, 1049,  985,  319, 1229,  316, 1229,  323,    0, 1004,
     1007,    0,  976,  974,  974,  234,  991,  394,  974,  987,
      971,  976,  982,  977,  349,  971,  965,  969,  979,  976,
      961,  978,    0,    0,    0,  964,  965,  971,  961,    0,
        0,  969,  954,  963,  957,    0,  966,  963,  965,  948,
      958,  961,  959,    0,  949,  953,    0,  956, 1012, 1011,
     1229, 1010,  387,  951,  389,  955,  996,  990, 1229,  983,
      959,  985,  938,  929,  928,  945,  942,  417,  945,  935,

      931,  923,  923,  926,  925,  971,  968,  916,  918,  929,
      932,  917,  965,  911,  909,  909,    0,    0,    0,  922,
      923,    0,    0,    0,    0,    0,    0,  925,  918,  918,
      910,  971,  972, 1229,  971, 1229,  421,  425,  427,  413,
      968, 1229,  948,  946,  948,  902,  896,  898,  899,  910,
      894,  439,  906,    0,    0,  891,  888,  900,  933,    0,
      891,  893,  897,  888,  893,  931,  888,  891,    0,  878,
      875,  881,  942,  887,  885,    0,  889,  940,  448, 1229,
      333,  450,  454,  939,  938,  885,  915,  912,    0,  868,
      863,  875,  867,  866,  456,  857,  871,  866,  874,  873,

      860,  868,  870,  857,    0,  897,  855,    0,    0,    0,
      851,  862,    0,    0,  907,  878,  414,  862,  913,  460,
     1229,  370,  912, 1229,  911, 1229,  877,  857,    0,    0,
      840,    0,  840,  853,  853,  837,  832,  847,  834,  848,
      828,    0,  827,  845,    0,  844,  838,  839,  833, 1229,
      883,  852,  428,  853,  442,  847,  855,  830,  831,  814,
      811,  819,  825,  462,  815,    0,    0,  828,    0,  808,
      826,  824,  823,  823,  443,  835,  444,  832,  830,  816,
      817,  808,  801,  814,  814,  466,  809,  812,  811,    0,
      810,  797,  791,  815,  463,  806,  466,  813,  815,  794,

      790,  789,  788,  780,  798,    0,  839,  459,  796,    0,
        0,    0,  845,  813,  332,  801,  470,  799,  799,  784,
        0,  784,  787,  778,    0, 1229,  462,    0,  786,  806,
      474,  803,  476,  804,  789,  772, 1229,  761,  767,  468,
      778,  788,  480,  797,  482,  786,  795,  768,  763,  766,
      471,  752,  780,  484,  779,  485,  774,  777,  761,  752,
     1229,  476,  744,  779,  487,  755,  491,    0,  706,    0,
      693,  482,  696,  705,  493,  712,  488,    0,  694,  479,
      668,  585,  494,  593,  496,  561,  487,  542,  516,  499,
      512,  501, 1229,  493,  505,  541,  555,  500,  504,  307,

      496,  547,  545, 1229,  542,  538, 1229,  559,  563,  524,
      480,  527,  524, 1229,  520,  519, 1229,  507,  505,  441,
      500,  428,  337,  303,  234,  237,  144,  114,   92, 1229,
     1229,  568,  578,  588,  593,  603,  608,  617,  627,  636,
      646,  656,  666,  676,  686,  696,  700,  710,  720,  730,
      737,  746,  756,  766,  776,  786,  796,  806
    } ;

static yyconst flex_int16_t yy_def[759] =
    {   0,
      731,    1,  731,  731,  731,  732,  731,  733,  731,  731,
      731,  734,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  735,  735,
      735,  735,  735,  731,  731,  731,  731,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  731,  731,  731,  731,  731,  732,  731,
      733,  731,  733,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  734,  731,  734,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  736,  731,   84,   21,   22,
      731,  731,  731,  737,  731,  731,  731,  731,  731,  731,

      731,  731,  735,  735,  735,  738,  739,  735,  731,  731,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  740,  736,
      731,  731,  731,  731,  731,  731,  731,  737,  731,  731,
      735,  735,  738,  731,  738,  739,  731,  739,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,

      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  741,  731,  731,  731,  731,  742,  731,  731,
      731,  731,  731,  731,  740,  731,  731,  731,  731,  731,
      731,  731,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,

      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  741,  731,  731,  731,  743,  731,  742,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  731,  744,  743,
      731,  745,  731,  731,  731,  731,  731,  731,  731,  735,
      735,  735,  735,  735,  735,  735,  735,  731,  735,  735,

      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  731,  744,  731,  745,  731,  731,  746,  731,  731,
      731,  731,  735,  735,  735,  735,  735,  735,  735,  735,
      731,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  747,  731,  746,  746,  731,
      746,  731,  748,  749,  750,  735,  735,  735,  735,  735,
      735,  735,  735,  731,  731,  735,  735,  735,  735,  735,

      735,  735,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  731,  735,  735,  751,  731,  746,  731,  748,  748,
      731,  748,  749,  731,  750,  731,  735,  735,  735,  735,
      735,  735,  735,  731,  731,  731,  735,  735,  735,  735,
      735,  735,  735,  735,  735,  735,  735,  735,  731,  731,
      751,  731,  746,  731,  748,  735,  735,  735,  735,  731,
      731,  731,  735,  735,  735,  735,  735,  735,  735,  735,
      735,  735,  731,  731,  746,  731,  748,  735,  735,  735,
      735,  731,  731,  731,  735,  731,  752,  735,  735,  735,
      735,  735,  731,  731,  746,  731,  748,  735,  735,  735,

      735,  731,  731,  731,  735,  752,  752,  752,  735,  735,
      735,  735,  731,  731,  746,  731,  748,  735,  735,  735,
      735,  731,  731,  731,  735,  731,  752,  735,  731,  731,
      746,  731,  748,  735,  735,  735,  731,  731,  731,  752,
      731,  731,  746,  731,  748,  735,  735,  735,  731,  731,
      752,  731,  731,  746,  731,  748,  735,  735,  735,  731,
      731,  752,  731,  731,  746,  731,  748,  735,  735,  735,
      731,  752,  731,  731,  746,  731,  748,  735,  731,  752,
      731,  731,  746,  731,  748,  731,  752,  731,  731,  746,
      731,  748,  731,  752,  731,  753,  754,  731,  748,  752,

      731,  753,  753,  731,  754,  754,  731,  755,  756,  757,
      731,  755,  755,  731,  756,  756,  731,  757,  757,  731,
      757,  731,  731,  731,  731,  731,  731,  758,  758,  731,
        0,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731
    } ;

static yyconst flex_uint16_t yy_nxt[1314] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   23,   24,   25,
       26,   27,   28,   29,   29,   29,   29,   29,   30,   31,
       29,   29,   32,   29,   29,   29,   29,   33,   29,   29,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   45,   29,   46,   29,   29,   47,   29,   29,   29,
       29,   48,   49,   50,   51,   52,   53,   29,   29,   29,
       54,   55,   56,   57,   58,   62,   58,   58,   64,   70,
       71,   72,   75,   78,  730,   83,   80,   84,   84,   84,

       84,   84,   84,   84,   84,   96,  101,  102,   85,   79,
       81,   82,   73,   86,  106,  116,  730,  117,  107,  111,
      118,  132,  119,  112,   97,   87,   98,   99,  113,  133,
       63,  120,  114,   76,  123,  125,   62,  126,  121,  115,
      146,   75,   65,   66,  124,  122,  127,   67,  167,   58,
       68,   58,   58,  174,   69,   88,  128,   89,   89,   89,
       89,   89,   89,   90,   90,  136,  137,  129,  140,  150,
      130,  151,  167,  177,  220,   91,  138,  141,  182,  139,
       92,   63,   76,  183,  142,  158,   93,   94,  158,  213,
      216,  147,  221,  222,  228,  174,  214,   91,  175,  265,

      254,  217,  218,  229,   92,  230,  238,  255,  231,  223,
      266,  248,   93,  159,  178,   94,   88,  728,   90,   90,
       90,   90,   90,   90,   90,   90,  148,  148,  148,  148,
      148,  148,  148,  148,  233,  248,   91,  161,  166,  165,
      175,   92,  250,  162,  731,  166,  177,   93,  235,  148,
      148,  148,  148,  148,  148,  148,  148,  236,   91,  259,
      239,  161,  260,  165,  166,   92,  250,  263,  264,  162,
      240,  166,  731,   93,   84,   84,   84,   84,   84,   84,
       84,   84,  283,  284,  246,  272,  325,  178,  395,  396,
      247,  727,  156,  157,  163,  273,  163,  157,  247,  164,

      164,  164,  164,  164,  164,  164,  164,  726,  246,  185,
      325,  186,  187,  188,  156,  157,  247,  189,  710,  626,
      387,  157,  190,  387,  247,  191,  192,  193,  194,  195,
      196,  243,  388,  243,  480,  480,  244,  244,  244,  244,
      244,  244,  244,  244,  164,  164,  164,  164,  164,  164,
      164,  164,  164,  164,  164,  164,  164,  164,  164,  164,
      251,  328,  326,  344,  327,  389,  252,  631,  327,  406,
      345,  249,  521,  407,  725,  249,  244,  244,  244,  244,
      244,  244,  244,  244,  251,  328,  326,  517,  437,  389,
      327,  438,  252,  249,  327,  398,  724,  398,  398,  249,

      244,  244,  244,  244,  244,  244,  244,  244,  440,  440,
      440,  440,  440,  440,  440,  440,  480,  484,  398,  157,
      398,  398,  437,  157,  555,  437,  479,  480,  482,  479,
      480,  483,  440,  440,  440,  440,  440,  440,  440,  440,
      495,  157,  495,  495,  521,  480,  521,  157,  399,  479,
      480,  482,  479,  553,  482,  520,  521,  495,  520,  495,
      495,  520,  521,  586,  520,  480,  586,  586,  521,  575,
      586,  626,  521,  587,  626,  477,  480,  606,  521,  481,
      626,  577,  480,  626,  521,  597,  480,  521,  626,  480,
      521,  626,  451,  521,  626,  480,  480,  595,  521,  626,

      723,  480,  481,  521,  518,  626,  521,  643,  522,  615,
      535,  645,  721,  722,  522,  656,  633,  721,  627,  719,
      617,  717,  717,  654,  675,  685,  714,  665,  667,  714,
      662,  536,  640,  672,  677,  720,  719,  680,  683,  651,
      707,  692,  703,  704,  707,  703,  694,  704,  690,  704,
      711,  700,  687,  697,  708,  699,  706,  707,  709,  706,
      713,  714,  701,  713,  716,  717,  698,  716,   59,   59,
      696,   59,   59,   59,   59,   59,   59,   59,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,  103,  103,

      103,  103,  103,  160,  160,  695,  160,  160,  160,  160,
      160,  160,  160,  168,  168,  693,  168,  173,  173,  173,
      173,  173,  173,  173,  173,  173,  173,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  245,  691,  689,
      245,  245,  245,  245,  245,  245,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  318,  318,  318,  318,
      318,  318,  318,  318,  318,  318,  380,  380,  380,  380,
      380,  380,  380,  380,  380,  380,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  478,  478,  478,  478,

      478,  478,  478,  478,  478,  478,  515,  515,  515,  515,
      519,  519,  519,  519,  519,  519,  519,  519,  519,  519,
      523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
      525,  525,  525,  525,  525,  525,  525,  525,  525,  525,
      551,  688,  551,  551,  551,  551,  551,  607,  686,  684,
      682,  681,  679,  678,  607,  607,  702,  702,  702,  702,
      702,  702,  702,  702,  702,  702,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  715,  715,  715,  715,
      715,  715,  715,  715,  715,  715,  718,  718,  676,  718,

      718,  718,  718,  718,  718,  718,  729,  729,  729,  729,
      729,  729,  729,  729,  729,  729,  674,  673,  671,  670,
      669,  668,  666,  664,  663,  661,  660,  659,  658,  657,
      655,  653,  652,  650,  649,  648,  647,  646,  644,  642,
      641,  639,  638,  637,  636,  635,  634,  632,  630,  629,
      628,  626,  625,  624,  623,  622,  621,  620,  619,  618,
      616,  614,  613,  612,  611,  610,  609,  608,  605,  604,
      603,  602,  601,  600,  599,  598,  596,  594,  593,  592,
      591,  590,  589,  588,  585,  584,  583,  582,  581,  580,
      579,  578,  576,  574,  550,  573,  572,  571,  570,  569,

      568,  567,  566,  565,  564,  563,  562,  561,  560,  559,
      558,  557,  556,  526,  524,  521,  554,  552,  550,  549,
      548,  547,  546,  545,  544,  543,  542,  541,  540,  539,
      538,  537,  534,  533,  532,  531,  530,  529,  528,  527,
      526,  524,  480,  516,  514,  513,  512,  511,  510,  509,
      508,  507,  506,  505,  504,  503,  502,  501,  500,  499,
      498,  497,  496,  494,  493,  492,  491,  490,  489,  488,
      487,  486,  485,  436,  434,  476,  475,  474,  473,  472,
      471,  470,  469,  468,  467,  466,  465,  464,  463,  462,
      461,  460,  459,  458,  457,  456,  455,  454,  453,  452,

      450,  449,  448,  447,  446,  445,  444,  443,  442,  388,
      441,  439,  436,  381,  434,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  415,  414,  413,  412,  411,  410,  409,  408,
      405,  404,  403,  402,  401,  400,  397,  394,  393,  392,
      391,  390,  386,  385,  384,  383,  319,  382,  381,  379,
      378,  313,  377,  376,  375,  374,  373,  372,  371,  370,
      369,  368,  367,  366,  365,  364,  363,  362,  361,  360,
      359,  358,  357,  356,  355,  354,  353,  352,  351,  350,
      349,  348,  347,  346,  343,  342,  341,  340,  339,  338,

      337,  336,  335,  334,  333,  332,  331,  330,  329,  324,
      323,  322,  321,  320,  319,  317,  316,  315,  314,  313,
      311,  310,  309,  308,  307,  306,  305,  304,  303,  302,
      301,  300,  299,  298,  297,  296,  295,  294,  293,  292,
      291,  290,  289,  288,  287,  286,  285,  282,  281,  280,
      279,  278,  277,  276,  275,  274,  271,  270,  269,  268,
      267,  262,  261,  258,  257,  256,  731,  731,  253,  159,
      242,  241,  237,  234,  232,  227,  226,  225,  224,  219,
      215,  212,  211,  210,  209,  208,  207,  206,  205,  204,
      203,  202,  201,  200,  199,  198,  197,  184,  181,  180,

      179,  172,  171,  170,  169,  155,  731,  154,  153,  152,
      149,  731,  145,  144,  143,  135,  134,  131,  110,  109,
      108,  105,  104,  100,   95,   77,   60,  731,    3,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,

      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731
    } ;

static yyconst flex_int16_t yy_chk[1314] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    5,    8,    5,    5,    9,   10,
       10,   11,   12,   16,  729,   19,   18,   19,   19,   19,

       19,   19,   19,   19,   19,   25,   27,   27,   20,   16,
       18,   18,   11,   20,   32,   39,  728,   39,   32,   38,
       40,   46,   40,   38,   25,   20,   25,   25,   38,   46,
        8,   41,   38,   12,   42,   43,   61,   43,   41,   38,
       55,   74,    9,    9,   42,   41,   43,    9,   93,   58,
        9,   58,   58,  106,    9,   21,   44,   21,   21,   21,
       21,   21,   21,   21,   21,   49,   49,   44,   50,   66,
       44,   66,   93,  107,  137,   21,   49,   50,  113,   49,
       21,   61,   74,  113,   50,   85,   21,   21,   85,  133,
      135,   55,  137,  138,  143,  173,  133,   21,  106,  186,

      172,  135,  135,  143,   21,  144,  152,  172,  144,  138,
      186,  162,   21,   85,  107,   21,   22,  727,   22,   22,
       22,   22,   22,   22,   22,   22,   64,   64,   64,   64,
       64,   64,   64,   64,  148,  162,   22,   89,  165,   92,
      173,   22,  167,   89,   89,   92,  176,   22,  150,  148,
      148,  148,  148,  148,  148,  148,  148,  150,   22,  182,
      152,   89,  182,   92,  165,   22,  167,  185,  185,   89,
      152,   92,   89,   22,   84,   84,   84,   84,   84,   84,
       84,   84,  203,  203,  161,  192,  248,  176,  336,  336,
      161,  726,   84,   84,   91,  192,   91,   84,  246,   91,

       91,   91,   91,   91,   91,   91,   91,  725,  161,  115,
      248,  115,  115,  115,   84,   84,  161,  115,  700,  700,
      324,   84,  115,  324,  246,  115,  115,  115,  115,  115,
      115,  156,  324,  156,  615,  481,  156,  156,  156,  156,
      156,  156,  156,  156,  163,  163,  163,  163,  163,  163,
      163,  163,  164,  164,  164,  164,  164,  164,  164,  164,
      168,  252,  251,  269,  326,  328,  168,  615,  251,  345,
      269,  164,  522,  345,  724,  164,  243,  243,  243,  243,
      243,  243,  243,  243,  168,  252,  251,  481,  383,  328,
      326,  383,  168,  164,  251,  338,  723,  338,  338,  164,

      244,  244,  244,  244,  244,  244,  244,  244,  385,  385,
      385,  385,  385,  385,  385,  385,  517,  440,  398,  244,
      398,  398,  437,  244,  522,  437,  438,  438,  439,  438,
      553,  439,  440,  440,  440,  440,  440,  440,  440,  440,
      452,  244,  452,  452,  555,  575,  577,  244,  338,  479,
      479,  482,  479,  517,  482,  483,  483,  495,  483,  495,
      495,  520,  520,  564,  520,  595,  564,  586,  597,  553,
      586,  608,  617,  564,  627,  437,  631,  586,  633,  438,
      640,  555,  643,  651,  645,  577,  654,  656,  662,  665,
      677,  680,  398,  667,  672,  675,  683,  575,  685,  687,

      722,  690,  479,  692,  482,  694,  699,  631,  483,  595,
      495,  633,  721,  720,  520,  645,  617,  719,  608,  718,
      597,  716,  715,  643,  665,  677,  713,  654,  656,  712,
      651,  495,  627,  662,  667,  711,  710,  672,  675,  640,
      706,  685,  696,  696,  705,  696,  687,  703,  683,  702,
      701,  694,  680,  690,  698,  692,  697,  697,  699,  697,
      708,  708,  695,  708,  709,  709,  691,  709,  732,  732,
      689,  732,  732,  732,  732,  732,  732,  732,  733,  733,
      733,  733,  733,  733,  733,  733,  733,  733,  734,  734,
      734,  734,  734,  734,  734,  734,  734,  734,  735,  735,

      735,  735,  735,  736,  736,  688,  736,  736,  736,  736,
      736,  736,  736,  737,  737,  686,  737,  738,  738,  738,
      738,  738,  738,  738,  738,  738,  738,  739,  739,  739,
      739,  739,  739,  739,  739,  739,  739,  740,  684,  682,
      740,  740,  740,  740,  740,  740,  741,  741,  741,  741,
      741,  741,  741,  741,  741,  741,  742,  742,  742,  742,
      742,  742,  742,  742,  742,  742,  743,  743,  743,  743,
      743,  743,  743,  743,  743,  743,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  746,  746,  746,  746,

      746,  746,  746,  746,  746,  746,  747,  747,  747,  747,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      749,  749,  749,  749,  749,  749,  749,  749,  749,  749,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      751,  681,  751,  751,  751,  751,  751,  752,  679,  676,
      674,  673,  671,  669,  752,  752,  753,  753,  753,  753,
      753,  753,  753,  753,  753,  753,  754,  754,  754,  754,
      754,  754,  754,  754,  754,  754,  755,  755,  755,  755,
      755,  755,  755,  755,  755,  755,  756,  756,  756,  756,
      756,  756,  756,  756,  756,  756,  757,  757,  666,  757,

      757,  757,  757,  757,  757,  757,  758,  758,  758,  758,
      758,  758,  758,  758,  758,  758,  664,  663,  660,  659,
      658,  657,  655,  653,  652,  650,  649,  648,  647,  646,
      644,  642,  641,  639,  638,  636,  635,  634,  632,  630,
      629,  624,  623,  622,  620,  619,  618,  616,  614,  613,
      609,  607,  605,  604,  603,  602,  601,  600,  599,  598,
      596,  594,  593,  592,  591,  589,  588,  587,  585,  584,
      583,  582,  581,  580,  579,  578,  576,  574,  573,  572,
      571,  570,  568,  565,  563,  562,  561,  560,  559,  558,
      557,  556,  554,  552,  551,  549,  548,  547,  546,  544,

      543,  541,  540,  539,  538,  537,  536,  535,  534,  533,
      531,  528,  527,  525,  523,  519,  518,  516,  515,  512,
      511,  507,  506,  504,  503,  502,  501,  500,  499,  498,
      497,  496,  494,  493,  492,  491,  490,  488,  487,  486,
      485,  484,  478,  477,  475,  474,  473,  472,  471,  470,
      468,  467,  466,  465,  464,  463,  462,  461,  459,  458,
      457,  456,  453,  451,  450,  449,  448,  447,  446,  445,
      444,  443,  441,  435,  433,  432,  431,  430,  429,  428,
      421,  420,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  400,  399,

      397,  396,  395,  394,  393,  392,  391,  390,  388,  387,
      386,  384,  382,  380,  379,  378,  376,  375,  373,  372,
      371,  370,  369,  368,  367,  365,  364,  363,  362,  359,
      358,  357,  356,  352,  351,  350,  349,  348,  347,  346,
      344,  343,  342,  341,  340,  339,  337,  335,  334,  333,
      331,  330,  323,  322,  321,  320,  318,  317,  316,  315,
      314,  312,  311,  310,  308,  307,  306,  304,  303,  302,
      301,  300,  299,  298,  297,  296,  295,  293,  291,  290,
      289,  286,  285,  284,  283,  280,  277,  276,  275,  274,
      273,  272,  271,  270,  268,  267,  266,  265,  264,  263,

      262,  261,  260,  259,  258,  257,  255,  254,  253,  245,
      242,  241,  240,  239,  238,  237,  236,  235,  234,  233,
      232,  231,  230,  229,  228,  227,  226,  225,  224,  223,
      222,  221,  220,  219,  218,  217,  216,  215,  213,  212,
      210,  209,  208,  207,  206,  205,  204,  202,  201,  200,
      199,  198,  196,  195,  194,  193,  191,  190,  189,  188,
      187,  184,  183,  181,  180,  179,  178,  175,  171,  158,
      154,  153,  151,  149,  145,  142,  141,  140,  139,  136,
      134,  131,  130,  129,  128,  127,  126,  125,  124,  123,
      122,  121,  120,  119,  118,  117,  116,  114,  112,  111,

      108,  105,  104,  102,   98,   83,   76,   69,   68,   67,
       65,   63,   53,   52,   51,   48,   47,   45,   37,   35,
       33,   31,   30,   26,   23,   15,    7,    3,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,

      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  731,  731
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#ifndef _WIN32
#include <limits.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

#ifdef USE_WINDOWS
#include <windows.h>
#endif

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner, gboolean has_line);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);

#if (YY_FLEX_MAJOR_VERSION > 2) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION > 6)) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION == 6) && (YY_FLEX_SUBMINOR_VERSION >= 1))
#define IS_EOF 0
#else
#define IS_EOF EOF
#endif

#line 1188 "giscanner/scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * _in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * _out_str  );

			int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 82 "giscanner/scannerlexer.l"


#line 1413 "giscanner/scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 732 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1229 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 84 "giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 90 "giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 92 "giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 94 "giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 95 "giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 96 "giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 98 "giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 99 "giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 100 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 101 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 102 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 103 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 104 "giscanner/scannerlexer.l"
{ ++lineno; return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 105 "giscanner/scannerlexer.l"
{ ++lineno; return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 106 "giscanner/scannerlexer.l"
{ ++lineno; return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 107 "giscanner/scannerlexer.l"
{ ++lineno; return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 108 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 110 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, FALSE); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 111 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, TRUE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 112 "giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 113 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 114 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 115 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 116 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 117 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 118 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 119 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 120 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 121 "giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 122 "giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 123 "giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 124 "giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 125 "giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 126 "giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 127 "giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 128 "giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 129 "giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 130 "giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 131 "giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 132 "giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 133 "giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 134 "giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 135 "giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 136 "giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 137 "giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 138 "giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 139 "giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 140 "giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 141 "giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 142 "giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 143 "giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 144 "giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 145 "giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 146 "giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 147 "giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 148 "giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 149 "giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 150 "giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 151 "giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 152 "giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 153 "giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 154 "giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 155 "giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 156 "giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 157 "giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 158 "giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 159 "giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 160 "giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 161 "giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 162 "giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 164 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 165 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 166 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 167 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 168 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 169 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 170 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 171 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 172 "giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 173 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 174 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 175 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 176 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 177 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 178 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 179 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 180 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 181 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 182 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 183 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 184 "giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 185 "giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 186 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 187 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 188 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 189 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 190 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore */ }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 191 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 192 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 193 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 194 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 195 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 196 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 197 "giscanner/scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 199 "giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 200 "giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 202 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 203 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 204 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 205 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 207 "giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 209 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 210 "giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 211 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 212 "giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 213 "giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 214 "giscanner/scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 215 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 216 "giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 217 "giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 218 "giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 219 "giscanner/scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 220 "giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 221 "giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 222 "giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 223 "giscanner/scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 224 "giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 225 "giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 226 "giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 227 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 228 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 229 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 230 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 231 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 232 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 233 "giscanner/scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 234 "giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 235 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 236 "giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 237 "giscanner/scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 238 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 239 "giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 240 "giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 241 "giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 242 "giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 243 "giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 244 "giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 245 "giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 246 "giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 247 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 248 "giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 250 "giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 252 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 253 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 254 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 256 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 257 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 158:
/* rule 158 can match eol */
YY_RULE_SETUP
#line 259 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 159:
/* rule 159 can match eol */
YY_RULE_SETUP
#line 260 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 160:
/* rule 160 can match eol */
YY_RULE_SETUP
#line 262 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 161:
/* rule 161 can match eol */
YY_RULE_SETUP
#line 263 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 265 "giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 267 "giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2311 "giscanner/scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 732 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 732 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 731);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 267 "giscanner/scannerlexer.l"



static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != IS_EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  /* We don't want to include <windows.h> as it clashes horribly
   * with token names from scannerparser.h. So just declare
   * GetFullPathNameA() here unless we already defined it, like
   * in giscanner.c.
   */
#ifndef USE_WINDOWS
  extern __stdcall GetFullPathNameA(const char*, int, char*, char**);
#endif
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != IS_EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != IS_EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != IS_EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    fprintf(stderr, "%s:%d: unexpected character `%c'\n", filename, lineno, yytext[0]);
    g_free (filename);
  }
}

